<?php

/**
 * @file
 * Utility code related to menus and menu blocks.
 */

/**
 * Helper function to see if a menu is one of our special USWDS menus.
 */
function _uswds_get_region_for_menu($menu_region) {
  $special_menu_regions = array(
    'primary_menu' => USWDS_MENU_REGION_PRIMARY,
    'secondary_menu' => USWDS_MENU_REGION_SECONDARY,
    'mobile_menu' => USWDS_MENU_REGION_MOBILE,
    'footer_menu' => USWDS_MENU_REGION_FOOTER,
    'sidebar_first' => USWDS_MENU_REGION_SIDE,
  );
  if (empty($special_menu_regions[$menu_region])) {
    return FALSE;
  }
  return $special_menu_regions[$menu_region];
}

/**
 * Helper function to recursively mark menu links as being in a certain region.
 */
function _uswds_mark_navigation_items_by_region(&$element, $region) {
  foreach (element_children($element) as $key) {
    // Drop a note in all the menu links for later use in uswds_menu_link().
    $element[$key]['#uswds_menu_region'] = $region;
    // Recurse if there are children.
    if (!empty($element[$key]['#below'])) {
      _uswds_mark_navigation_items_by_region($element[$key]['#below'], $region);
    }
  }
}

/**
 * Helper function to tell whether a menu tree is one-dimensional (flat).
 */
function _uswds_is_menu_tree_flat($tree) {
  foreach (element_children($tree) as $key) {
    $link = $tree[$key]['#original_link'];
    if (1 != $link['depth'] || ($link['has_children'] && $link['expanded'])) {
      return FALSE;
    }
  }
  return TRUE;
}
